@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef BOOKMARKPLUGIN_H
@@ -9,7 +9,7 @@
 
 #include <QMenu>
 
-class QFileSystemWatcher;
+class c2bFileSystemWatcher;
 
 
 class bookmarkPlugin : public QMenu
@@ -28,7 +28,7 @@ signals:
 
 
 private:
-    QFileSystemWatcher* _fsw;
+    c2bFileSystemWatcher* _fsw;
     QString _bookmark_file;
     QString iconProvider(const QString& fn, const QString& iconFile);
 
