@@ -1,13 +1,14 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2b.h"
 
 #include "c2bClipboard.h"
 #include "c2bConfigure.h"
+#include "dialog.h"
 #include "ui_proxyDialog.h"
 
 #include <QAuthenticator>
@@ -35,7 +36,7 @@ c2b::c2b(QWidget* main, QObject* parento) : QObject(parento)
         connect(_c2b_network, SIGNAL(proxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)),
                 this, SLOT(proxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)));
         connect(_c2b_network, SIGNAL(downloadProgress(qint64, qint64)), this, SLOT(updateDownloadProgress(qint64, qint64)));
-        _download_progress = new QProgressDialog(_c2b_main);
+        _download_progress = new QProgressDialog(_c2b_main, dialog::flags);
         _download_progress->setWindowTitle("Downloading...");
         _download_progress->reset();
         connect(_download_progress, SIGNAL(canceled()), _c2b_network, SLOT(cancelDownload()));
@@ -125,7 +126,7 @@ void c2b::updateDownloadProgress(qint64 bytesReceived, qint64 bytesTotal)
 
 void c2b::proxyAuthenticationRequired(const QNetworkProxy& proxy, QAuthenticator* auth)
 {
-    QDialog dialog(_c2b_main);
+    QDialog dialog(_c2b_main, dialog::flags);
     Ui::proxyDialog proxyDialog;
     proxyDialog.setupUi(&dialog);
     dialog.setWindowTitle(tr("Proxy %1 Authentication - cb2Bib").arg(proxy.hostName()));
