@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *
  *   Class implementation of the approximate search algorithm
@@ -12,6 +12,17 @@
 #include "cb2bib_utilities.h"
 #include "triads.h"
 
+#if QT_VERSION >= 0x050400
+static const QRegularExpression::PatternOptions _qre_pattern_options(
+    QRegularExpression::DontCaptureOption |
+    QRegularExpression::UseUnicodePropertiesOption |
+    QRegularExpression::OptimizeOnFirstUsageOption);
+#else
+static const QRegularExpression::PatternOptions _qre_pattern_options(
+    QRegularExpression::DontCaptureOption |
+    QRegularExpression::UseUnicodePropertiesOption);
+#endif
+
 
 approximatePattern::approximatePattern() : compositePattern()
 {}
@@ -33,12 +44,14 @@ void approximatePattern::setPattern(const QString& pattern, const Qt::CaseSensit
     if (_string.length() < 5)
     {
         _regexp.setPattern(escape(_string, _case_sensitivity));
+        _regexp.setPatternOptions(_qre_pattern_options);
         return;
     }
     // Single word: Allow 1 error (1 missing / 3 excess), anywhere
     if (wordCount(_string) == 1)
     {
         _regexp.setPattern(wordPattern(_string, _case_sensitivity));
+        _regexp.setPatternOptions(_qre_pattern_options);
         return;
     }
     // Multiple words
@@ -48,6 +61,7 @@ void approximatePattern::setPattern(const QString& pattern, const Qt::CaseSensit
     if (_string_pieces.count() < 3) // Cases: "qq pp", "qqq pp", etc
     {
         _regexp.setPattern(wordPattern(_string, _case_sensitivity));
+        _regexp.setPatternOptions(_qre_pattern_options);
         return;
     }
     _is_multipattern = true;
@@ -110,8 +124,7 @@ void approximatePattern::setPattern(const QString& pattern, const Qt::CaseSensit
     {
         const int ii(_index.at(i));
         _submatchers[i] = substringMatcher(submatcher.at(ii), _case_sensitivity);
-        _subregexps[i] = QRegExp(subpattern.at(ii), Qt::CaseSensitive, QRegExp::RegExp2);
-        _subregexps[i].setMinimal(false);
+        _subregexps[i].setPattern(subpattern.at(ii));
         _substrings.append(substring.at(ii));
     }
     _p0.resize(_subpattern_count);
