@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *
  *   Class implementation of the approximate search algorithm
@@ -40,7 +40,7 @@ public:
             return false;
         }
         else
-            return _regexp.indexIn(str) != -1;
+            return _regexp.match(str).hasMatch();
     }
     inline int indexIn(const QString& str, const int from = 0) const
     {
@@ -59,8 +59,9 @@ public:
         }
         else
         {
-            index = _regexp.indexIn(str, from);
-            _matched_length = _regexp.matchedLength();
+            _regexp_match = _regexp.match(str, from);
+            _matched_length = _regexp_match.capturedLength();
+            index = _regexp_match.capturedStart();
         }
         return index;
     }
@@ -85,6 +86,7 @@ private:
     QStringList _string_pieces;
     QStringList _suffixes;
     QVector<substringMatcher> _submatchers;
+    mutable QRegularExpressionMatch _regexp_match;
 
 };
 
