@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bibSearcher.h"
@@ -531,7 +531,7 @@ const QString bibSearcher::highlight(const QString& abstract) const
 
 const QString bibSearcher::location(const QString& fn, const bibReference& ref) const
 {
-    const QString at("<a href=\"Edit reference '%1' from file [%2:%3]\" class=\"anchor\">"
+    const QString at("<a href=\"%1:%2\" class=\"anchor\">"
                      "<img src=\":/icons/icons/edit16.png\" alt=\"action\" width=\"16\" height=\"16\" /></a>");
-    return at.arg(ref.citeidName).arg(fn).arg(ref.positionValue);
+    return at.arg(QDir::cleanPath(fn)).arg(ref.positionValue);
 }
