@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "collectionIndex.h"
@@ -26,9 +26,14 @@ static const int _in_long_document_sentence_repetition(3);
 static const int _in_short_document_sentence_repetition(2);
 static const int _inter_document_sentence_repetition(3);
 
+#if QT_VERSION >= 0x050400
 static const QRegularExpression::PatternOptions _qre_pattern_options(
     QRegularExpression::UseUnicodePropertiesOption |
     QRegularExpression::OptimizeOnFirstUsageOption);
+#else
+static const QRegularExpression::PatternOptions _qre_pattern_options(
+    QRegularExpression::UseUnicodePropertiesOption);
+#endif
 
 #define C2B_DEBUG_COLLECTIONINDEX 0
 
