@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "compositePattern.h"
@@ -27,11 +27,7 @@ compositePattern::compositePattern() :
     _is_multipattern(false),
     _subpattern_count(0),
     _matched_length(-1)
-{
-    _regexp.setCaseSensitivity(Qt::CaseSensitive); // Setting _regexp case sensitive for efficiency
-    _regexp.setMinimal(false);
-    _regexp.setPatternSyntax(QRegExp::RegExp2);
-}
+{}
 
 compositePattern::compositePattern(const QString& pattern, const Qt::CaseSensitivity cs) :
     _string(pattern.simplified()),
@@ -39,23 +35,19 @@ compositePattern::compositePattern(const QString& pattern, const Qt::CaseSensiti
     _is_multipattern(false),
     _subpattern_count(0),
     _matched_length(-1)
-{
-    _regexp.setCaseSensitivity(Qt::CaseSensitive); // Setting _regexp case sensitive for efficiency
-    _regexp.setMinimal(false);
-    _regexp.setPatternSyntax(QRegExp::RegExp2);
-}
+{}
 
 
 QString compositePattern::escape(const QString& str, const Qt::CaseSensitivity cs)
 {
     if (cs == Qt::CaseSensitive)
-        return QRegExp::escape(str);
+        return QRegularExpression::escape(str);
     QString scaped;
     for (int i = 0; i < str.length(); ++i)
         if (str.at(i).isLetter())
             scaped += QString("[%1%2]").arg(str.at(i).toUpper()).arg(str.at(i).toLower());
         else
-            scaped += QRegExp::escape(str.at(i));
+            scaped += QRegularExpression::escape(str.at(i));
     return scaped;
 }
 
