@@ -1,13 +1,13 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef COMPOSITEPATTERN_H
 #define COMPOSITEPATTERN_H
 
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QStringList>
 #include <QVector>
 
@@ -29,11 +29,11 @@ public:
     {
         return _substrings;
     }
-    inline const QRegExp& regexp() const
+    inline const QRegularExpression& regexp() const
     {
         return _regexp;
     }
-    inline const QVector<QRegExp>& subregexps() const
+    inline const QVector<QRegularExpression>& subregexps() const
     {
         return _subregexps;
     }
@@ -63,10 +63,10 @@ protected:
     void set_sort_index();
 
     QList<double> _ranks;
-    QRegExp _regexp;
+    QRegularExpression _regexp;
     QString _string;
     QStringList _substrings;
-    QVector<QRegExp> _subregexps;
+    QVector<QRegularExpression> _subregexps;
     QVector<int> _index;
     Qt::CaseSensitivity _case_sensitivity;
     bool _is_multipattern;
