@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef METADATAPARSER_H
@@ -22,7 +22,7 @@ class metadataParser : public QObject
 
 public:
     explicit metadataParser(QObject* parento = 0);
-    metadataParser(coreBibParser* bp, QObject* parento = 0);
+    metadataParser(coreBibParser* cbp, QObject* parento = 0);
     inline ~metadataParser() {}
 
     bool insertMetadata(const bibReference& ref, const QString& fn, QString* error = 0) const;
