@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "searchPattern.h"
@@ -133,18 +133,36 @@ searchPattern::matcher::matcher(const QString& pattern, const Type t, const Qt::
     break;
     case RegularExpression:
     {
+#if QT_VERSION >= 0x050400
+        const QRegularExpression::PatternOptions po(
+            QRegularExpression::DontCaptureOption |
+            QRegularExpression::UseUnicodePropertiesOption |
+            QRegularExpression::OptimizeOnFirstUsageOption);
+#else
+        const QRegularExpression::PatternOptions po(
+            QRegularExpression::DontCaptureOption |
+            QRegularExpression::UseUnicodePropertiesOption);
+#endif
         regexp.setPattern(pattern);
-        regexp.setCaseSensitivity(cs);
-        regexp.setPatternSyntax(QRegExp::RegExp2);
-        regexp.setMinimal(true);
+        regexp.setPatternOptions(cs == Qt::CaseSensitive ? po : po | QRegularExpression::CaseInsensitiveOption);
     }
     break;
     case Wildcard:
     {
-        regexp.setPattern(pattern);
-        regexp.setCaseSensitivity(cs);
-        regexp.setPatternSyntax(QRegExp::Wildcard);
-        regexp.setMinimal(true);
+#if QT_VERSION >= 0x050400
+        const QRegularExpression::PatternOptions po(
+            QRegularExpression::InvertedGreedinessOption |
+            QRegularExpression::DontCaptureOption |
+            QRegularExpression::UseUnicodePropertiesOption |
+            QRegularExpression::OptimizeOnFirstUsageOption);
+#else
+        const QRegularExpression::PatternOptions po(
+            QRegularExpression::InvertedGreedinessOption |
+            QRegularExpression::DontCaptureOption |
+            QRegularExpression::UseUnicodePropertiesOption);
+#endif
+        regexp.setPattern(_wildcard_escaped(pattern));
+        regexp.setPatternOptions(cs == Qt::CaseSensitive ? po : po | QRegularExpression::CaseInsensitiveOption);
         signature = triads::textSignature(pattern);
     }
     break;
@@ -166,7 +184,7 @@ bool searchPattern::matcher::match(const QString& contents) const
     case FixedString:
         return strexp.indexIn(contents) != -1;
     default:
-        return regexp.indexIn(contents) != -1;
+        return regexp.match(contents).hasMatch();
     }
 }
 
@@ -213,8 +231,22 @@ int searchPattern::matcher::index(const QString& contents, const int from) const
         length = strexp.pattern().length();
         return i;
     default:
-        i = regexp.indexIn(contents, from);
-        length = regexp.matchedLength();
+        regexp_match = regexp.match(contents, from);
+        i = regexp_match.capturedStart();
+        length = regexp_match.capturedLength();
         return i;
     }
 }
+
+QString searchPattern::matcher::_wildcard_escaped(const QString& pattern)
+{
+    QString scaped;
+    for (int i = 0; i < pattern.length(); ++i)
+        if (pattern.at(i) == '*')
+            scaped += ".*";
+        else if (pattern.at(i) == '?')
+            scaped += '.';
+        else
+            scaped += QRegularExpression::escape(pattern.at(i));
+    return scaped;
+}
