@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef SEARCHPATTERN_H
@@ -12,8 +12,8 @@
 #include "wordMatcher.h"
 #include "wordPattern.h"
 
-#include <QRegExp>
 #include <QList>
+#include <QRegularExpression>
 
 
 class searchPattern
@@ -83,12 +83,13 @@ private:
     {
         matcher(const QString& pattern, const Type t, const Qt::CaseSensitivity cs);
 
-        QRegExp regexp;
+        QRegularExpression regexp;
         QString signature;
         QStringMatcher strexp;
         QVector<QString> subsignatures;
         Type type;
         approximatePattern appexp;
+        mutable QRegularExpressionMatch regexp_match;
         mutable int length;
         wordMatcher cwordexp;
         wordPattern wordexp;
@@ -97,6 +98,8 @@ private:
         bool match(const documentContents& contents) const;
         int index(const QString& contents, const int from) const;
 
+        static QString _wildcard_escaped(const QString& pattern);
+
         inline static bool _match_signature(const QString& ps, const QString& cs)
         {
             const int pl(ps.length()); // Always pl > 0
@@ -113,6 +116,14 @@ private:
                         return true;
             return false;
         }
+        inline static bool _match(const QRegularExpression& submatcher, const QString& psignature, const documentContents& contents)
+        {
+            // Skip signature check for patterns that do not define it
+            if (psignature.length() == 0 || _match_signature(psignature, contents.signature()))
+                return submatcher.match(contents.text()).hasMatch();
+            else
+                return false;
+        }
         template <typename T> inline static bool _match(const T& submatcher, const QString& psignature, const documentContents& contents)
         {
             // Skip signature check for patterns that do not define it
