@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef SETTINGS_H
@@ -105,7 +105,7 @@ public:
     {
         return _application_pid;
     }
-    void setDefaultValue(const QString& key, const QVariant& value);
+    void setDefaultValue(const QString& key, const QVariant& defaulValue);
 
     static bool isConsoleMode(int& argc, char** argv);
     static bool isSingleApplicationMode(int& argc, char** argv);
