@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "texToHtml.h"
@@ -14,7 +14,6 @@
 
 texToHtml::texToHtml() : texParser()
 {
-    _has_inline_equations_rx = QRegExp("\\$.{1,100}\\$");
     _macro_arguments_rx = QRegExp("\\}\\s*\\[\\s*(\\d+)\\s*\\]\\s*\\{");
     _named_extern_url_rx = QRegExp("_((?:file|http|https|ftp)://(?:[^\\s\\n\\r\\[]+))\\[([^\\]]*)\\]");
     _named_url_rx = QRegExp("\\b((?:file|http|https|ftp)://(?:[^\\s\\n\\r\\[]+))\\[([^\\]]*)\\]");
@@ -23,7 +22,6 @@ texToHtml::texToHtml() : texParser()
 
     _close_subsection = false;;
     _close_subsubsection = false;;
-    _has_equation = false;;
     _make_index = false;;
     _use_relative_links = false;;
     _index_anchors = 0;;
@@ -44,7 +42,6 @@ QString texToHtml::toHtml(const QString& tex)
     _cites.clear();
     _close_subsection = false;
     _close_subsubsection = false;
-    _has_equation = false;
     _html.clear();
     _index = "<ul>\n";
     _index_anchors = 0;
@@ -71,10 +68,10 @@ QString texToHtml::toHtml(const QString& tex)
 
     if (_settingsP->value("c2bAnnote/IncludeCSS").toBool())
     {
-        QString css(c2bUtils::fileToString(_settingsP->fileName("c2bAnnote/AnnoteCssFile")));
+        QString css(c2bUtils::fileToString(_settingsP->fileName("c2bAnnote/AnnoteCssFile")).trimmed());
         if (css.isEmpty())
             css = c2bUtils::fileToString(":/htm/htm/tex2html.css");
-        tex2html.replace("GET_CSS", "\n <style type=\"text/css\">\n" + css.trimmed() + "\n </style>\n");
+        tex2html.replace("GET_CSS", "<style type=\"text/css\">\n" + css.trimmed() + "\n</style>\n");
     }
     else
     {
@@ -94,18 +91,11 @@ QString texToHtml::toHtml(const QString& tex)
     referencesToHtml(&reference_list_html);
     tex2html.replace("GET_REFERENCES", reference_list_html);
     citesToHtml(&_html);
-    if (_has_equation || _html.contains(_has_inline_equations_rx))
-    {
-        QString jsmath_head(c2bUtils::fileToString(":/htm/htm/tex2html_jsmath_head.html"));
-        QString jsmath_dn(_settingsP->fileName("c2bAnnote/jsMathDirectory"));
-        if (_use_relative_links)
-            jsmath_dn = _current_dir.relativeFilePath(jsmath_dn);
-        jsmath_head.replace("GET_JSMATH_ROOT_DIRECTORY", jsmath_dn);
-        jsmath_head.replace("GET_JSMATH_MACROS", _tex_macros);
-        tex2html.replace("GET_JSMATH_HEAD", jsmath_head);
-    }
+    QString mathjax_head(c2bUtils::fileToString(_settingsP->fileName("c2bAnnote/MathJaxHeaderFile")).trimmed());
+    if (mathjax_head.isEmpty())
+        tex2html.remove("GET_MATHJAX_HEAD");
     else
-        tex2html.remove("GET_JSMATH_HEAD");
+        tex2html.replace("GET_MATHJAX_HEAD", mathjax_head);
     if (_make_index && _index_anchors > 1)
     {
         _index = c2bUtils::fileToString(":/htm/htm/tex2html_index.html").arg(_index);
@@ -160,11 +150,6 @@ void texToHtml::parseElement(const QString& p, const QString& e, const QString&
     }
     else if (e == "title")
         _title = toHtmlString(v);
-    else if (e == "equation")
-    {
-        _html += QString("\n<div id=\"math\" class=\"math\">\n%1\n</div>\n\n").arg(v.trimmed());
-        _has_equation = true;
-    }
     else if (e == "itemize")
     {
         const QStringList items(v.trimmed().split("\\item ", QString::SkipEmptyParts));
@@ -175,10 +160,11 @@ void texToHtml::parseElement(const QString& p, const QString& e, const QString&
         _html += QString("\n<div id=\"abstract\" class=\"abstract\">\n%1\n</div><br /><hr />\n\n").arg(toHtmlString(v.trimmed()));
     else if (e == "verbatim")
         _html += QString("\n<pre>%1</pre>\n\n").arg(v);
-    else if (e == "newcommand")
-        extractMacro(v);
+    // TODO. Possibly extractMacro is not needed since MathJax
+    // else if (e == "newcommand")
+    //    extractMacro(v);
     else
-        _html += QString("\n<pre>\n%1\n</pre>\n\n").arg(p);
+        _html += QString("\n<div>\n%1\n</div>\n\n").arg(p);
 }
 
 void texToHtml::parseComment(const QString& p)
