@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef TEXTOHTML_H
@@ -32,7 +32,6 @@ private:
     QHash<QString, int> _cites;
     QList<QRegExp> _tex_macro_names_rx;
     QRegExp _extern_url_rx;
-    QRegExp _has_inline_equations_rx;
     QRegExp _macro_arguments_rx;
     QRegExp _named_extern_url_rx;
     QRegExp _named_url_rx;
@@ -45,7 +44,6 @@ private:
     QString _title;
     bool _close_subsection;
     bool _close_subsubsection;
-    bool _has_equation;
     bool _make_index;
     bool _use_relative_links;
     coreBibParser _cbp;
