@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "wordPattern.h"
@@ -56,8 +56,7 @@ void wordPattern::setPattern(const QString& pattern, const Type type, const Qt::
     {
         const int ii(_index.at(i));
         _submatchers[i] = QStringMatcher(substring.at(ii), _case_sensitivity);
-        _subregexps[i] = QRegExp(subpattern.at(ii), Qt::CaseSensitive, QRegExp::RegExp2);
-        _subregexps[i].setMinimal(false);
+        _subregexps[i].setPattern(subpattern.at(ii));
         _substrings.append(substring.at(ii));
     }
     _is_multipattern = _subpattern_count > 1;
