@@ -1,19 +1,19 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bAnnote.h"
 
 #include "c2b.h"
+#include "c2bFileSystemWatcher.h"
 #include "c2bSettings.h"
 #include "c2bUtils.h"
 #include "c2bWebBrowser.h"
 
 #include <texToHtml.h>
 
-#include <QFileSystemWatcher>
 #include <QLabel>
 #include <QMessageBox>
 #include <QShortcut>
@@ -54,7 +54,7 @@ c2bAnnote::c2bAnnote(QWidget* parentw) : QMainWindow(parentw)
     connect(_settingsP, SIGNAL(newSettings()), this, SLOT(loadSettings()));
 
     _t2h = new texToHtml;
-    _fsw = new QFileSystemWatcher(this);
+    _fsw = new c2bFileSystemWatcher(this);
     connect(_fsw, SIGNAL(fileChanged(const QString&)), this, SLOT(annote()));
     disconnect(_view_port->viewReloadAction, 0, 0, 0);
     connect(_view_port->viewReloadAction, SIGNAL(triggered()), this, SLOT(update()));
