@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BANNOTE_H
@@ -10,7 +10,7 @@
 #include <QMainWindow>
 
 
-class QFileSystemWatcher;
+class c2bFileSystemWatcher;
 class c2bSettings;
 class c2bWebBrowser;
 class texToHtml;
@@ -28,9 +28,9 @@ public:
 
 
 private:
-    QFileSystemWatcher* _fsw;
     QString _annote_filename;
     QString _html_filename;
+    c2bFileSystemWatcher* _fsw;
     c2bSettings* _settingsP;
     c2bWebBrowser* _view_port;
     texToHtml* _t2h;
