@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bCiterView.h"
@@ -375,6 +375,10 @@ void c2bCiterView::keyPressEvent(QKeyEvent* qevent)
         keywordDocumentSearch();
         qevent->accept();
         return;
+    case Qt::Key_W:
+        emit openAnnote();
+        qevent->accept();
+        return;
     case Qt::Key_Escape:
         emit hideCiter();
         qevent->accept();
