@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BCLIPEDIT_H
@@ -26,7 +26,7 @@ public:
 
     void setText(const QString& text, const QString& tagged_text = QString());
     void setTaggedViewMode(bool tagged_view);
-    void insertTag(const QString& field);
+    void insertTag(const QString& tag);
     void updatePlainText(const QString& text);
 
 
