@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bClipboard.h"
@@ -22,17 +22,15 @@ c2bClipboard::c2bClipboard(QObject* parento) : QObject(parento)
     if (_supports_selection)
         _cbs_text = _cb->text(QClipboard::Selection);
 
-    // Setting timer
+    // Set polling
     _interval = 1000;
 #ifdef C2B_USE_CBPOLL
     _poll = new clipboardPoll();
     connect(_poll, SIGNAL(clipboardChanged(bool)), this, SLOT(newClipboardData(bool)));
 #else
-#ifdef Q_OS_UNIX
     _timer = new QTimer(this);
     connect(_timer, SIGNAL(timeout()), this, SLOT(checkData()));
 #endif
-#endif
 }
 
 c2bClipboard::~c2bClipboard()
@@ -45,40 +43,34 @@ c2bClipboard::~c2bClipboard()
 
 void c2bClipboard::checkData()
 {
-    if (_supports_selection)
+    if (_cb_text != _cb->text(QClipboard::Clipboard))
     {
-        if (_cb_text != _cb->text(QClipboard::Clipboard))
-        {
-            _cb_text = _cb->text(QClipboard::Clipboard);
-            _cbs_text = _cb->text(QClipboard::Selection);
-            emit cbDataChanged(_cb_text);
-        }
-        else if (_cbs_text != _cb->text(QClipboard::Selection))
-        {
-            _cbs_text = _cb->text(QClipboard::Selection);
-            emit cbDataChanged(_cbs_text);
-        }
+        _cb_text = _cb->text(QClipboard::Clipboard);
+        emit cbDataChanged(_cb_text);
     }
-    else
+    if (_supports_selection && _cbs_text != _cb->text(QClipboard::Selection))
     {
-        if (_cb_text != _cb->text(QClipboard::Clipboard))
-        {
-            _cb_text == _cb->text(QClipboard::Clipboard);
-            emit cbDataChanged(_cb_text);
-        }
+        _cbs_text = _cb->text(QClipboard::Selection);
+        emit cbDataChanged(_cbs_text);
     }
 }
 
 void c2bClipboard::dataChanged()
 {
-    _cb_text = _cb->text(QClipboard::Clipboard);
-    emit cbDataChanged(_cb_text);
+    if (_cb_text != _cb->text(QClipboard::Clipboard))
+    {
+        _cb_text = _cb->text(QClipboard::Clipboard);
+        emit cbDataChanged(_cb_text);
+    }
 }
 
 void c2bClipboard::selectionChanged()
 {
-    _cbs_text = _cb->text(QClipboard::Selection);
-    emit cbDataChanged(_cbs_text);
+    if (_supports_selection && _cbs_text != _cb->text(QClipboard::Selection))
+    {
+        _cbs_text = _cb->text(QClipboard::Selection);
+        emit cbDataChanged(_cbs_text);
+    }
 }
 
 void c2bClipboard::setConnected(bool zconn)
@@ -96,9 +88,7 @@ void c2bClipboard::setConnected(bool zconn)
 #ifdef C2B_USE_CBPOLL
         _poll->startT(_interval);
 #else
-#ifdef Q_OS_UNIX
         _timer->start(_interval);
-#endif
 #endif
     }
     else
@@ -106,9 +96,7 @@ void c2bClipboard::setConnected(bool zconn)
 #ifdef C2B_USE_CBPOLL
         _poll->stopT();
 #else
-#ifdef Q_OS_UNIX
         _timer->stop();
-#endif
 #endif
         disconnect(_cb, SIGNAL(dataChanged()), this, SLOT(dataChanged()));
         if (_supports_selection)
@@ -116,34 +104,10 @@ void c2bClipboard::setConnected(bool zconn)
     }
 }
 
-const QString c2bClipboard::text()
-{
-    return _cb->text(QClipboard::Clipboard);
-}
-
 void c2bClipboard::newClipboardData(bool selectionMode)
 {
     if (selectionMode)
-        checkSelectionData();
+        selectionChanged();
     else
-        checkClipboardData();
-}
-
-void c2bClipboard::checkSelectionData()
-{
-    if (_supports_selection)
-        if (_cbs_text != _cb->text(QClipboard::Selection))
-        {
-            _cbs_text = _cb->text(QClipboard::Selection);
-            emit cbDataChanged(_cbs_text);
-        }
-}
-
-void c2bClipboard::checkClipboardData()
-{
-    if (_cb_text != _cb->text(QClipboard::Clipboard))
-    {
-        _cb_text = _cb->text(QClipboard::Clipboard);
-        emit cbDataChanged(_cb_text);
-    }
+        dataChanged();
 }
