@@ -1,13 +1,14 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BCLIPBOARD_H
 #define C2BCLIPBOARD_H
 
 #include <QObject>
+
 #include <QClipboard>
 #include <QTimer>
 
@@ -18,7 +19,7 @@
     Implements clipboard functionality as required by cb2Bib This should fix
     acrobat, mozilla, qt 3.3.3 issues Using clipboardPoll
 
-    @author Pere Constans
+    STATUS: DEPRECATED
 */
 
 #ifdef C2B_USE_CBPOLL
@@ -32,7 +33,7 @@ public:
     explicit c2bClipboard(QObject* parento = 0);
     ~c2bClipboard();
 
-    const QString text();
+
     void setConnected(bool);
 
 
@@ -50,16 +51,12 @@ private:
 #ifdef C2B_USE_CBPOLL
     clipboardPoll* _poll;
 #else
-#ifdef Q_OS_UNIX
     QTimer* _timer;
 #endif
-#endif
 
 
 private slots:
-    void checkClipboardData();
     void checkData();
-    void checkSelectionData();
     void dataChanged();
     void newClipboardData(bool selectionMode);
     void selectionChanged();
