@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bEditor.h"
@@ -23,6 +23,7 @@
 #include "findDialog.h"
 
 #include <bibSearcher.h>
+#include <texToHtml.h>
 
 #include <QCloseEvent>
 #include <QDir>
@@ -209,7 +210,7 @@ summary="Summary table of Additional Functionality">
 */
 
 
-c2bEditor::c2bEditor(const QString& file, const QString& mode, QWidget* main, QWidget* parentw) : QMainWindow(parentw)
+c2bEditor::c2bEditor(const QString& file, const Mode mode, QWidget* main, QWidget* parentw) : QMainWindow(parentw)
 {
     _editor_fn = QDir::toNativeSeparators(file);
     _editor_mode = mode;
@@ -221,7 +222,7 @@ c2bEditor::c2bEditor(const QString& file, const QString& mode, QWidget* main, QW
 c2bEditor::c2bEditor(const QString& file, bibSearcher* searcher, QWidget* main, QWidget* parentw) : QMainWindow(parentw)
 {
     _editor_fn = QDir::toNativeSeparators(file);
-    _editor_mode = "BibTeX";
+    _editor_mode = BibTeX;
     _c2b_mainP = main;
     _searcherP = searcher;
     initEditor();
@@ -240,7 +241,7 @@ void c2bEditor::initEditor()
     setAttribute(Qt::WA_DeleteOnClose);
 
     _settingsP = c2bSettingsP;
-    if (_editor_mode == "BibTeX")
+    if (_editor_mode == BibTeX)
         _bpP = c2b::bibParser();
     else
         _bpP = 0;
@@ -310,7 +311,7 @@ void c2bEditor::initEditor()
 
 void c2bEditor::setEditorMode()
 {
-    if (_editor_mode == "RegExp")
+    if (_editor_mode == RegExp)
     {
         _shP = new c2bREHighlighter(_editorP->document());
         ui.fileExecAction->setText(tr("Restart Recognition"));
@@ -320,7 +321,7 @@ void c2bEditor::setEditorMode()
         ui.toolBar->setVisible(_settingsP->value("c2bEditor/ToolBar", true).toBool());
         setViewMode(true);
     }
-    else if (_editor_mode == "NetQInfo")
+    else if (_editor_mode == NetQInfo)
     {
         _shP = new c2bREHighlighter(_editorP->document());
         ui.fileExecAction->setText(tr("Restart Network Query"));
@@ -330,13 +331,24 @@ void c2bEditor::setEditorMode()
         ui.toolBar->setVisible(_settingsP->value("c2bEditor/ToolBar", true).toBool());
         setViewMode(true);
     }
-    else if (_editor_mode == "JAbbrev")
+    else if (_editor_mode == JAbbrev)
     {
         ui.fileExecAction->setVisible(false);
         ui.toolBar->setVisible(_settingsP->value("c2bEditor/ToolBar", true).toBool());
         setViewMode(true);
     }
-    else if (_editor_mode == "BibTeX")
+    else if (_editor_mode == Annote)
+    {
+        _shP = new c2bBibHighlighter(_editorP->document());
+        ui.fileExecAction->setText(tr("View Note in External Browser"));
+        ui.fileExecAction->setStatusTip(tr("View Note in External Browser"));
+        _settingsP->setKeysequence("Shortcuts/Editor/", ui.fileExecAction);
+        _editorP->setLaTeXActions();
+        connect(this, SIGNAL(execute()), this, SLOT(htmlView()));
+        ui.toolBar->setVisible(_settingsP->value("c2bEditor/ToolBar", true).toBool());
+        setViewMode(true);
+    }
+    else if (_editor_mode == BibTeX)
     {
         // Editor
         _shP = new c2bBibHighlighter(_editorP->document());
@@ -454,7 +466,7 @@ bool c2bEditor::closeEditor()
             return false;
     }
     _settingsP->setValue("c2bEditor/size", size());
-    if (_editor_mode == "BibTeX")
+    if (_editor_mode == BibTeX)
         _settingsP->setValue("c2bEditor/state", saveState());
     _settingsP->setValue("c2bEditor/ToolBar", !ui.toolBar->isHidden());
     return true;
@@ -471,7 +483,7 @@ void c2bEditor::isModified(int position, int charsRemoved, int charsAdded)
 
 void c2bEditor::fileOpen()
 {
-    if (_editor_mode == "BibTeX")
+    if (_editor_mode == BibTeX)
     {
         const QString filename(c2bFileDialog::getOpenFilename(this, "Select a BibTeX filename", _editor_fn, "BibTeX (*.bib)"));
         if (!filename.isEmpty())
@@ -506,8 +518,10 @@ bool c2bEditor::fileSave()
 bool c2bEditor::fileSaveAs()
 {
     QString filename;
-    if (_editor_mode == "BibTeX")
+    if (_editor_mode == BibTeX)
         filename = c2bFileDialog::getSaveFilename(this, QString(), _editor_fn, "BibTeX (*.bib);;All (*)");
+    else if (_editor_mode == Annote)
+        filename = c2bFileDialog::getSaveFilename(this, QString(), _editor_fn, "LaTeX (*.tex);;All (*)");
     else
         filename = c2bFileDialog::getSaveFilename(this, QString(), _editor_fn, "Text (*.txt);;All (*)");
     if (filename.isEmpty() || filename.contains("unnamed_"))
@@ -590,7 +604,7 @@ void c2bEditor::reload(const QString& fn)
 {
     // This function must be called ONLY in BibTeX mode
     // Pointers are undefined otherwise
-    if (_editor_mode != "BibTeX" || _editor_fn != fn)
+    if (_editor_mode != BibTeX || _editor_fn != fn)
         return;
 
     if (ui.fileSaveAction->isEnabled())
@@ -660,6 +674,16 @@ void c2bEditor::updateMetadata()
     um.update(_editor_fn, _editorP->toPlainText());
 }
 
+void c2bEditor::htmlView()
+{
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+    const QString html_filename(_editor_fn + ".html");
+    texToHtml t2h;
+    t2h.toHtml(c2bUtils::fileToString(_editor_fn), html_filename);
+    c2bUtils::openFile(html_filename);
+    QApplication::restoreOverrideCursor();
+}
+
 void c2bEditor::postProcess()
 {
     c2bPostprocess* ppBib = new c2bPostprocess(_editor_fn, this);
