@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BEDITOR_H
@@ -32,7 +32,9 @@ class c2bEditor : public QMainWindow
     Q_OBJECT
 
 public:
-    c2bEditor(const QString& file, const QString& mode, QWidget* main, QWidget* parentw = 0);
+    enum Mode {Annote, BibTeX, JAbbrev, NetQInfo, RegExp};
+
+    c2bEditor(const QString& file, const Mode mode, QWidget* main, QWidget* parentw = 0);
     c2bEditor(const QString& file, bibSearcher* searcher, QWidget* main, QWidget* parentw = 0);
 
     ~c2bEditor();
@@ -65,6 +67,7 @@ protected slots:
     void fileOpen();
     void helpCb2Bib();
     void helpEditor();
+    void htmlView();
     void isModified(int position, int charsRemoved, int charsAdded);
     void journalsToAbbreviated();
     void journalsToFull();
@@ -81,6 +84,7 @@ protected slots:
 
 
 private:
+    Mode _editor_mode;
     QDockWidget* _dockWidgetP;
     QLabel* _lineLabelP;
     QLabel* _overwriteLabelP;
@@ -88,7 +92,6 @@ private:
     QStackedWidget* _stackedWidgetP;
     QString _edit_reference_at_position;
     QString _editor_fn;
-    QString _editor_mode;
     QSyntaxHighlighter* _shP;
     QWidget* _c2b_mainP;
     Ui::c2bEditor ui;
