@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BFILEDIALOG_H
@@ -38,7 +38,7 @@ private:
     ~c2bFileDialog();
 
     QString _current_file;
-    QString exec(const QString& path);
+    QString fileName(const QString& path);
     c2bSettings* settings;
     fileIconProvider* fip;
     static QString _caption(const QString& generic, const QString& caption);
