@@ -1,18 +1,18 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bNetworkQueryInfo.h"
 
 #include "c2b.h"
 #include "c2bBibParser.h"
+#include "c2bFileSystemWatcher.h"
 #include "c2bSettings.h"
 #include "c2bUtils.h"
 
 #include <QAction>
-#include <QFileSystemWatcher>
 #include <QTextStream>
 #include <QUrl>
 
@@ -21,7 +21,7 @@ c2bNetworkQueryInfo::c2bNetworkQueryInfo(QObject* parento) : QObject(parento)
 {
     _bpP = c2b::instance()->bibParser();
     connect(c2bSettingsP, SIGNAL(newSettings()), this, SLOT(loadSettings()));
-    _fsw = new QFileSystemWatcher(this);
+    _fsw = new c2bFileSystemWatcher(this);
     connect(_fsw, SIGNAL(fileChanged(const QString&)), this, SLOT(parseBookmarks()));
     loadSettings();
 }
