@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BNETWORKQUERYINFO_H
@@ -11,8 +11,8 @@
 #include <QStringList>
 
 class QAction;
-class QFileSystemWatcher;
 class c2bBibParser;
+class c2bFileSystemWatcher;
 
 
 /**
@@ -33,11 +33,11 @@ public:
 
 
 private:
-    QFileSystemWatcher* _fsw;
     QList<QAction*> BookmarkActionList;
     QString NetworkFile;
     QString _current_selection;
     QStringList BookmarkList;
+    c2bFileSystemWatcher* _fsw;
     const c2bBibParser* _bpP;
 
 
