@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bReferenceList.h"
@@ -374,13 +374,13 @@ void c2bReferenceList::openUrl()
 
 void c2bReferenceList::openLink(const QUrl& ln)
 {
-    QString ln_str(ln.toString());
+    QString ln_str(QUrl::fromPercentEncoding(ln.toEncoded()));
     if (ln_str.isEmpty())
         c2b::showMessage(tr("No link available for this reference."));
     else if (ln_str.startsWith("Select reference "))
         scrollToReference(ln_str.remove(QRegExp("\\D")));
-    else if (ln_str.startsWith("Edit reference"))
-        emit openFile(ln_str.replace(QRegExp("^.+\\[(.+)\\]$"), "\\1"));
+    else if (ln_str.contains(QRegExp(":\\d+$")))
+        emit openFile(ln_str);
     else
         c2bUtils::openFile(ln_str, parentWidget());
 }
