@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bSettings.h"
@@ -104,7 +104,7 @@ void c2bSettings::setDefaults()
     _default_keysequences["Shortcuts/cb2Bib/Restart Recognition"] = QKeySequence(Qt::ALT + Qt::Key_R);
     _default_keysequences["Shortcuts/cb2Bib/Select BibTeX File"] = QKeySequence(Qt::ALT + Qt::Key_S);
     _default_keysequences["Shortcuts/cb2Bib/Select Document File"] = QKeySequence(Qt::ALT + Qt::Key_F);
-    _default_keysequences["Shortcuts/cb2Bib/Start Annote"] = QKeySequence(Qt::ALT + Qt::Key_A);
+    _default_keysequences["Shortcuts/cb2Bib/Annote Editor"] = QKeySequence(Qt::ALT + Qt::Key_A);
     _default_keysequences["Shortcuts/cb2Bib/Toggle Reference Tabs"] = QKeySequence(Qt::Key_F4);
     _default_keysequences["Shortcuts/cb2Bib/View Tagged Clipboard Data"] = QKeySequence();
     _default_keysequences["Shortcuts/cb2Bib/Write Metadata to Document"] = QKeySequence(Qt::ALT + Qt::Key_W);
@@ -128,6 +128,7 @@ void c2bSettings::setDefaults()
     _default_keysequences["Shortcuts/Editor/Toggle Editing and Browsing"] = QKeySequence(Qt::CTRL + Qt::Key_Tab);
     _default_keysequences["Shortcuts/Editor/Toggle Word Wrapping"] = QKeySequence();
     _default_keysequences["Shortcuts/Editor/Update Documents Metadata"] = QKeySequence();
+    _default_keysequences["Shortcuts/Editor/View Note in External Browser"] = QKeySequence();
     _default_keysequences["Shortcuts/Editor/Web Search Settings"] = QKeySequence();
     _default_keysequences["Shortcuts/Editor/Web Search by Author"] = QKeySequence();
     _default_keysequences["Shortcuts/Editor/Web Search by Title"] = QKeySequence();
