@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #define C2B_CHECK_CAPITALIZATION 0
@@ -23,6 +23,8 @@
 
 c2bTests::c2bTests() : cout(*(new QTextStream(stdout)))
 {
+    cout.setCodec("UTF-8");
+
     cout << "============" << endl;
     cout << "cb2Bib tests" << endl;
     cout << "============" << endl;
@@ -120,24 +122,34 @@ void c2bTests::write_information()
     cout << "-------------------------" << endl;
     cout << endl;
     cout << "Version: cb2bib " << C2B_VERSION << endl;
-#if C2B_USE_LZO
+#ifdef C2B_USE_LZO
     cout << "Compression: lzo2" << endl;
 #else
     cout << "Compression: zlib" << endl;
 #endif
-#if C2B_USE_WEBKIT
+#if QT_VERSION >= 0x050400
+    cout << "Optimized PCRE: yes" << endl;
+#else
+    cout << "Optimized PCRE: no" << endl;
+#endif
+#ifdef C2B_USE_QWEBKIT
     cout << "Compiled against QtWebKit: yes" << endl;
 #else
     cout << "Compiled against QtWebKit: no" << endl;
 #endif
-#if C2B_USE_CBPOLL
+#ifdef C2B_USE_QWEBENGINE
+    cout << "Compiled against QtWebEngine: yes" << endl;
+#else
+    cout << "Compiled against QtWebEngine: no" << endl;
+#endif
+#ifdef C2B_USE_CBPOLL
     cout << "Clipboard polling: yes" << endl;
 #else
     cout << "Clipboard polling: no" << endl;
 #endif
     cout << "Application binary path: " << QCoreApplication::instance()->applicationDirPath() << endl;
     cout << "Application hardcoded data path: " << C2B_DATA_DIR << endl;
-#ifdef Q_OS_MACX
+#ifdef Q_OS_MACOS
     QString C2B_DATA_DIR_MAC(C2B_DATA_DIR);
     if (QDir(C2B_DATA_DIR + "/data/").exists())
         C2B_DATA_DIR_MAC = QDir::cleanPath(C2B_DATA_DIR + '/');
