@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bTextEdit.h"
@@ -57,23 +57,7 @@ void c2bTextEdit::setBibTeXActions()
     pasteCurrentBibTeXAction->setStatusTip(tr("Paste current BibTeX"));
     _settingsP->setKeysequence("Shortcuts/Editor/", pasteCurrentBibTeXAction);
 
-    c2bUtils::addSeparator(this);
-    convertSelection2LaTeXAction = new QAction(this);
-    addAction(convertSelection2LaTeXAction);
-    convertSelection2LaTeXAction->setText(tr("Selection to LaTeX"));
-    convertSelection2LaTeXAction->setStatusTip(tr("Convert selection to LaTeX"));
-    _settingsP->setKeysequence("Shortcuts/Editor/", convertSelection2LaTeXAction);
-    connect(convertSelection2LaTeXAction, SIGNAL(triggered()), this, SLOT(convert2LaTeX()));
-    convertSelection2LaTeXAction->setEnabled(false);
-    connect(this, SIGNAL(copyAvailable(bool)), convertSelection2LaTeXAction, SLOT(setEnabled(bool)));
-    convertSelection2UnicodeAction = new QAction(this);
-    addAction(convertSelection2UnicodeAction);
-    convertSelection2UnicodeAction->setText(tr("Selection to Unicode"));
-    convertSelection2UnicodeAction->setStatusTip(tr("Convert selection to Unicode"));
-    _settingsP->setKeysequence("Shortcuts/Editor/", convertSelection2UnicodeAction);
-    connect(convertSelection2UnicodeAction, SIGNAL(triggered()), this, SLOT(convert2Unicode()));
-    convertSelection2UnicodeAction->setEnabled(false);
-    connect(this, SIGNAL(copyAvailable(bool)), convertSelection2UnicodeAction, SLOT(setEnabled(bool)));
+    setLaTeXActions();
 
     c2bUtils::addSeparator(this);
     journalsToFullAction = new QAction(this);
@@ -95,6 +79,27 @@ void c2bTextEdit::setBibTeXActions()
     _settingsP->setKeysequence("Shortcuts/Editor/", updateMetadataAction);
 }
 
+void c2bTextEdit::setLaTeXActions()
+{
+    c2bUtils::addSeparator(this);
+    convertSelection2LaTeXAction = new QAction(this);
+    addAction(convertSelection2LaTeXAction);
+    convertSelection2LaTeXAction->setText(tr("Selection to LaTeX"));
+    convertSelection2LaTeXAction->setStatusTip(tr("Convert selection to LaTeX"));
+    _settingsP->setKeysequence("Shortcuts/Editor/", convertSelection2LaTeXAction);
+    connect(convertSelection2LaTeXAction, SIGNAL(triggered()), this, SLOT(convert2LaTeX()));
+    convertSelection2LaTeXAction->setEnabled(false);
+    connect(this, SIGNAL(copyAvailable(bool)), convertSelection2LaTeXAction, SLOT(setEnabled(bool)));
+    convertSelection2UnicodeAction = new QAction(this);
+    addAction(convertSelection2UnicodeAction);
+    convertSelection2UnicodeAction->setText(tr("Selection to Unicode"));
+    convertSelection2UnicodeAction->setStatusTip(tr("Convert selection to Unicode"));
+    _settingsP->setKeysequence("Shortcuts/Editor/", convertSelection2UnicodeAction);
+    connect(convertSelection2UnicodeAction, SIGNAL(triggered()), this, SLOT(convert2Unicode()));
+    convertSelection2UnicodeAction->setEnabled(false);
+    connect(this, SIGNAL(copyAvailable(bool)), convertSelection2UnicodeAction, SLOT(setEnabled(bool)));
+}
+
 void c2bTextEdit::contextMenuEvent(QContextMenuEvent* qevent)
 {
     QMenu* menu = createStandardContextMenu();
@@ -123,12 +128,12 @@ void c2bTextEdit::toggleWordWrapping()
         setLineWrapMode(QPlainTextEdit::WidgetWidth);
 }
 
-void c2bTextEdit::updatePlainText(const QString& newText)
+void c2bTextEdit::updatePlainText(const QString& text)
 {
     const int scrollPosition(verticalScrollBar()->value());
     const int cursorBlock(textCursor().blockNumber());
     const int cursorColumn(textCursor().columnNumber());
-    setPlainText(newText);
+    setPlainText(text);
 
     QTextBlock p = document()->begin();
     int i(0);
