@@ -1,7 +1,7 @@
 /***************************************************************************
  *   clipboardPoll, modified by Pere Constans for the cb2Bib, 2005
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *
  *
  *   Author and Copyright (C) 2003 by Lubos Lunak <l.lunak@kde.org>
@@ -86,7 +86,7 @@ private:
     };
     Atom xa_clipboard;
     Atom xa_timestamp;
-    bool changedTimestamp(SelectionData& sData, const XEvent& e);
+    bool changedTimestamp(SelectionData& sData, const XEvent& ev);
     bool checkTimestamp(SelectionData& sData);
     QTimer* timer;
     SelectionData clipboard;
