@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "qtsingleapplication/src/qtsingleapplication.h"
@@ -12,13 +12,8 @@
 #include "c2bSettings.h"
 #include "cb2Bib.h"
 
-#ifdef C2B_USE_WEBKIT
+#ifdef C2B_USE_QWEB
 #include "c2bAnnote.h"
-#ifdef C2B_STATIC_LINKING
-#include <QtPlugin>
-Q_IMPORT_PLUGIN(qjpeg)
-Q_IMPORT_PLUGIN(qgif)
-#endif
 #endif
 
 
@@ -33,12 +28,8 @@ int main(int argc, char* argv[])
     if (c2bSettings::isConsoleMode(argc, argv))
     {
         // Cannot use QCoreApplication, QTextDocument is required by c2bUtils::fromHtmlString
-#ifdef Q_OS_WIN
         // Needs also workaround c2bSettings::decodeFilename()
         QApplication app(argc, argv);
-#else
-        QApplication app(argc, argv);
-#endif
         app.setOrganizationName(C2B_ORGANIZATION);
         app.setApplicationName(C2B_APPLICATION);
         c2b_settings = c2bSettings::initSettings();
@@ -53,11 +44,13 @@ int main(int argc, char* argv[])
     else if (c2bSettings::isSingleApplicationMode(argc, argv))
     {
         // Avoid connecting to the graphic server. On Windows it would create a void window.
-        QtSingleCoreApplication* capp = new QtSingleCoreApplication(argc, argv);
-        const bool is_running = capp->sendMessage(QString());
-        delete capp;
-        if (is_running)
-            return code;
+        {
+            QtSingleCoreApplication* capp = new QtSingleCoreApplication(argc, argv);
+            const bool is_running = capp->sendMessage(QString());
+            delete capp;
+            if (is_running)
+                return code;
+        }
         QtSingleApplication app(argc, argv);
         if (app.isRunning()) // Activate local peer
             return code;
@@ -92,12 +85,12 @@ int main(int argc, char* argv[])
             }
             else if (c2b_settings->cl_view_annote)
             {
-#ifdef C2B_USE_WEBKIT
+#ifdef C2B_USE_QWEB
                 c2bAnnote c2B;
                 if (c2B.show())
                     code = app.exec();
 #else
-                fprintf(stdout, "The cb2Bib Annote is disabled. Recompile using WebKit library.\n");
+                fprintf(stdout, "The cb2Bib Annote is disabled. Recompile using QtWebKit or QtWebEngine library.\n");
 #endif
             }
             else
