@@ -1,11 +1,13 @@
 /***************************************************************************
- *   Copyright (C) 2004-2015 by Pere Constans
+ *   Copyright (C) 2004-2017 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.2. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.9.7. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
+#include "WinConsole.h"
+
+#include <QCoreApplication>
 #include <QFileInfo>
-#include <QProcess>
 
 int main(int argc, char* argv[])
 {
@@ -16,6 +18,8 @@ int main(int argc, char* argv[])
     QStringList arguments;
     for (int i = 1; i < argc; ++i)
         arguments.append(argv[i]);
-    const int code(QProcess::execute(exe, arguments));
+    QCoreApplication a(argc, argv);
+    WinConsole wc;
+    const int code(wc.execute(exe, arguments));
     return code;
 }
